@@ -1,9 +1,6 @@
 import torch
 from transformers import T5Tokenizer, T5ForConditionalGeneration, AutoTokenizer, AutoModelForSeq2SeqLM
 
-AutoTokenizer.from_pretrained("google/t5-v1_1-base")
-
-model = AutoModelForSeq2SeqLM.from_pretrained("google/t5-v1_1-base")
 def exists(val):
     return val is not None
 
